from setuptools import setup

setup(
    name='hanifx',
    version='0.1',
    py_modules=['my_code'],
    description='A simple greeting package',
    author='Hanif',
    author_email='sajim4653@gmail.com',
    url='https://hanif-storess.weebly.com',
)+



from setuptools import setup, find_packages

setup(
    name='hanifx',
    version='0.1',
    packages=find_packages(),
    description='A simple greeting package',
    author='Hanif',
    author_email='sajim4653@gmail.com',
    url='https://hanif-storess.weebly.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)

